[![pypi version](https://img.shields.io/pypi/v/neunorm.svg)](https://pypi.python.org/pypi/neunorm)
[![Build Status](https://travis-ci.org/scikit-beam/NeuNorm.svg?branch=master)](https://travis-ci.org/scikit-beam/NeuNorm)
[![codecov](https://codecov.io/gh/ornlneutronimaging/NeuNorm/branch/master/graph/badge.svg)](https://codecov.io/gh/ornlneutronimaging/NeuNorm)
[![Documentation Status](https://readthedocs.org/projects/neunorm/badge/?version=latest)](http://neunorm.readthedocs.io/en/latest/?badge=latest)


# normalization
Normalization of fits and tiff files
